==> payara-embedded-all-5.2020.4-sources.jar: com/sun/enterprise/deployment/annotation/introspection/AbstractAnnotationScanner.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 * Portions Copyright [2017] Payara Foundation and/or affiliates
 */

package com.sun.enterprise.deployment.annotation.introspection;

import java.util.HashSet;
import java.util.Set;

/**
 * Abstract superclass for instance-based annotation scanners.
 *
 * @author tjquinn
 */
public abstract class AbstractAnnotationScanner implements AnnotationScanner {
    
    /** holds the annotations of interest to the specific type of scanner */
    protected volatile Set<String> annotations=null;
    
    /** Creates a new instance of AbstractAnnotationScanner */
    public AbstractAnnotationScanner() {
    }
  
    /**
     * Invoked so the concrete subclass can populate the annotations set.
     * <p>
     * Concrete implementations of this method should add to the set one or more Strings 
     * corresponding to the annotations of interest.  
     *
     * @param annotationsSet the Set object to be populated
     */
    protected abstract void init(Set<String> annotationsSet);

    /**
     * Test if the passed constant pool string is a reference to 
     * a Type.TYPE annotation of a J2EE component
     *
     * @String value the constant pool info string 
     * @return true if it is an annotation reference of interest to this scanner
     */
    @Override
    public boolean isAnnotation(String value) {
        if (annotations==null) {
            synchronized(this) {
                if (annotations == null) {
                    annotations = new HashSet();
                    init(annotations);
                }
            }
        }
        return annotations.contains(value);
    }

    @Override
    public Set<String> getAnnotations() {
        return constantPoolToFQCN(annotations);
    }

    /**
     * For a set of annotations removes first and last character and replaces any / with .
     * <p>
     * i.e. @Properties{ to Properties
     * @param annotations
     * @return 
     */
    public static Set<String> constantPoolToFQCN(Set<String> annotations) {
        // for now I transform ConstantPoolInfo type in FQCN
        Set<String> fqcns = new HashSet<String>();
        for (String annotation : annotations) {
            String fqcn = annotation.substring(1, annotation.length()-1).replaceAll("/",".");
            fqcns.add(fqcn);
        }
        return fqcns;
    }
}

==> payara-embedded-all-6.2023.10-sources.jar: com/sun/enterprise/deployment/annotation/introspection/AbstractAnnotationScanner.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 * Portions Copyright [2017-2020] Payara Foundation and/or affiliates
 */

package com.sun.enterprise.deployment.annotation.introspection;

import java.util.HashSet;
import java.util.Set;

/**
 * Abstract superclass for instance-based annotation scanners.
 *
 * @author tjquinn
 */
public abstract class AbstractAnnotationScanner implements AnnotationScanner {
    
    /** holds the annotations of interest to the specific type of scanner */
    protected volatile Set<String> annotations=null;
    
    /** Creates a new instance of AbstractAnnotationScanner */
    public AbstractAnnotationScanner() {
    }
  
    /**
     * Invoked so the concrete subclass can populate the annotations set.
     * <p>
     * Concrete implementations of this method should add to the set one or more Strings 
     * corresponding to the annotations of interest.  
     *
     * @param annotationsSet the Set object to be populated
     */
    protected abstract void init(Set<String> annotationsSet);

    /**
     * Test if the passed constant pool string is a reference to 
     * a Type.TYPE annotation of a J2EE component
     *
     * @String value the constant pool info string 
     * @return true if it is an annotation reference of interest to this scanner
     */
    @Override
    public boolean isAnnotation(String value) {
        if (annotations==null) {
            synchronized(this) {
                if (annotations == null) {
                    annotations = new HashSet<>();
                    init(annotations);
                }
            }
        }
        return annotations.contains(value);
    }

    @Override
    public Set<String> getAnnotations() {
        return constantPoolToFQCN(annotations);
    }

    /**
     * For a set of annotations removes first and last character and replaces any / with .
     * <p>
     * i.e. @Properties{ to Properties
     * @param annotations
     * @return 
     */
    public static Set<String> constantPoolToFQCN(Set<String> annotations) {
        // for now I transform ConstantPoolInfo type in FQCN
        Set<String> fqcns = new HashSet<>();
        for (String annotation : annotations) {
            String fqcn = annotation.substring(1, annotation.length()-1).replaceAll("/",".");
            fqcns.add(fqcn);
        }
        return fqcns;
    }
}
